summaryrefslogtreecommitdiff
path: root/qadevOOo/tests/java/ifc/connection/_XConnector.java
diff options
context:
space:
mode:
Diffstat (limited to 'qadevOOo/tests/java/ifc/connection/_XConnector.java')
-rw-r--r--qadevOOo/tests/java/ifc/connection/_XConnector.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/qadevOOo/tests/java/ifc/connection/_XConnector.java b/qadevOOo/tests/java/ifc/connection/_XConnector.java
index 12ae67dedea3..17db38f45bf1 100644
--- a/qadevOOo/tests/java/ifc/connection/_XConnector.java
+++ b/qadevOOo/tests/java/ifc/connection/_XConnector.java
@@ -53,7 +53,7 @@ public class _XConnector extends MultiMethodTest {
/**
* Calls <code>accept()</code> method in a separate thread.
* Then stores exception thrown by call if it occured, or
* return value.
*/
protected class AcceptorThread extends Thread {
@@ -62,7 +62,7 @@ public class _XConnector extends MultiMethodTest {
*/
private XAcceptor acc = null ;
/**
* If exception occured during method call it is
* stored in this field.
*/
public Exception ex = null ;
@@ -167,7 +167,7 @@ public class _XConnector extends MultiMethodTest {
acceptorThread.acceptedCall.getDescription()) ;
} else {
if (acceptorThread.ex != null) {
- log.println("Exception occured in accept() thread :") ;
+ log.println("Exception occurred in accept() thread :") ;
acceptorThread.ex.printStackTrace(log) ;
}
@@ -53,7 +53,7 @@ public class _XConnector extends MultiMethodTest {
/**
* Calls <code>accept()</code> method in a separate thread.
- * Then stores exception thrown by call if it occured, or
+ * Then stores exception thrown by call if it occurred, or
* return value.
*/
@@ -62,7 +62,7 @@ public class _XConnector extends MultiMethodTest {
private XAcceptor acc = null ;
/**
- * If exception occured during method call it is
+ * If exception occurred during method call it is
* stored in this field.
*/